@@ -4,9 +4,9 @@ import ROOT
 
 __all__ = ['set_figure', 'get_figure', 'clear', 'suppress_root_warnings']
 
-from . import figure
-__all__.extend( figure.__all__ )
-from .figure import *
+from . import figures
+__all__.extend( figures.__all__ )
+from .figures import *
 
 global figure
 figure = Figure()
